Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/HuasoFoundries/phpPgAdmin6.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'src/classes/Misc.php')
-rw-r--r--src/classes/Misc.php9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/classes/Misc.php b/src/classes/Misc.php
index e6a17619..ad4302aa 100644
--- a/src/classes/Misc.php
+++ b/src/classes/Misc.php
@@ -6,6 +6,8 @@
namespace PHPPgAdmin;
+use PHPPgAdmin\Database\Postgres;
+
/**
* @file
* Class to hold various commonly used functions
@@ -64,6 +66,9 @@ class Misc
private $_reload_browser = false;
+ /**
+ * @var Postgres
+ */
private $_data;
private $_database;
@@ -279,9 +284,9 @@ class Misc
*
* @internal mixed $plaform placeholder that will receive the value of the platform
*
* @return null|\PHPPgAdmin\Database\ADOdbBase the database accessor instance
*/
- public function getDatabaseAccessor($database = '', $server_id = null): ?\PHPPgAdmin\Database\ADOdbBase
+ public function getDatabaseAccessor($database = '', $server_id = null): ?\PHPPgAdmin\Database\Postgres
{
$lang = $this->lang;
@@ -279,9 +284,9 @@ class Misc
* @internal mixed $plaform placeholder that will receive the value of the platform
*
- * @return null|\PHPPgAdmin\Database\ADOdbBase the database accessor instance
+ * @return null|\PHPPgAdmin\Database\Postgres the database accessor instance
*/